==> haskell-lsp-types-1.1.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.1.0.0
visibility:           public
id:                   lsp-types-1.1.0.0-32SjvBKGaGqDFUTTn7RNAX
key:                  lsp-types-1.1.0.0-32SjvBKGaGqDFUTTn7RNAX
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  bf40970098fdf4161e91573635dab317
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Progress Language.LSP.Types.Registration
    Language.LSP.Types.References Language.LSP.Types.Rename
    Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-8.10.4/site-local/lsp-types-1.1.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lsp-types-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lsp-types-1.1.0.0
hs-libraries:         HSlsp-types-1.1.0.0-32SjvBKGaGqDFUTTn7RNAX
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV deepseq-1.4.4.0
    dependent-sum-0.7.1.0-CvTxeIxTvQsGOJRQo4l1Ot
    dependent-sum-template-0.1.0.3-F2eTqiVTW1b1Sge8R3XYrM
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    hslogger-1.3.1.0-8ipL3Vi4TXI5YpLFy9Bzmk
    lens-5.0.1-GQ9qIy7F2QRLy6pB6lHgUn
    network-uri-2.6.4.1-J4xKR5bjyl4EwNDOZsZp7W
    rope-utf16-splay-0.3.2.0-4IzFahWrkUV1WC4j35Yf4w
    scientific-0.3.6.2-3drxgAmnSntDv0pyrC0U61
    some-1.0.2-44LyWDgy81mp7LRTzJ3Bh template-haskell-2.16.0.0
    temporary-1.3-7D6eUd59nrdDdMitYScslJ text-1.2.4.1
    unordered-containers-0.2.13.0-3zq6q89i05VC2WIEWnQHAq

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types-1.1.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.1.0.0
visibility:           public
id:                   lsp-types-1.1.0.0-3zO389Wmm7kH1R6DziqHfV
key:                  lsp-types-1.1.0.0-3zO389Wmm7kH1R6DziqHfV
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  2d55c2697f130fc4a6aefea1b136d6b8
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Progress Language.LSP.Types.Registration
    Language.LSP.Types.References Language.LSP.Types.Rename
    Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-8.10.4/site-local/lsp-types-1.1.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lsp-types-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lsp-types-1.1.0.0
hs-libraries:         HSlsp-types-1.1.0.0-3zO389Wmm7kH1R6DziqHfV
depends:
    aeson-1.5.6.0-8KXcI8eaJDb23YvdvZt7uT base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV deepseq-1.4.4.0
    dependent-sum-0.7.1.0-4QsQ0uldyNP6gIWI4NMwVk
    dependent-sum-template-0.1.0.3-IVfxGgEoJbWF2rwHOuTftb
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.1.0-3O2Bzk2rCtQQYcJkJ3vPV
    hslogger-1.3.1.0-4brPsN6LEUx1N3HWs34B1o
    lens-5.0.1-CE26d8f9KlGBxeehqIVbTQ
    network-uri-2.6.4.1-3mv7RWF0Ao3K2iKwg9OxVv
    rope-utf16-splay-0.3.2.0-5XouiTOYBnd8RfR7WuNhj3
    scientific-0.3.6.2-21jjdCL1aCqC58ACrk6SAS
    some-1.0.3-DOAyHBxu2Hi295GDOks7Sc template-haskell-2.16.0.0
    temporary-1.3-YlcfNISBGv11xPHCq9h8q text-1.2.4.1
    unordered-containers-0.2.13.0-Db75j8fMRzh4s5oxHejudG

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
